@@ -170,6 +170,8 @@ class CreateCfsFileSystemRequest(AbstractModel):
         :type FsName: str
         :param ResourceTags: 文件系统标签
         :type ResourceTags: list of TagInfo
+        :param ClientToken: 用于保证请求幂等性的字符串。该字符串由客户生成，需保证不同请求之间唯一，最大值不超过64个ASCII字符。若不指定该参数，则无法保证请求的幂等性。用于保证请求幂等性的字符串失效时间为2小时。
+        :type ClientToken: str
         """
         self.Zone = None
         self.NetInterface = None
@@ -181,6 +183,7 @@ class CreateCfsFileSystemRequest(AbstractModel):
         self.MountIP = None
         self.FsName = None
         self.ResourceTags = None
+        self.ClientToken = None
 
 
     def _deserialize(self, params):
@@ -199,6 +202,7 @@ class CreateCfsFileSystemRequest(AbstractModel):
                 obj = TagInfo()
                 obj._deserialize(item)
                 self.ResourceTags.append(obj)
+        self.ClientToken = params.get("ClientToken")
 
 
 class CreateCfsFileSystemResponse(AbstractModel):
